@@ -1,11 +1,12 @@
 from typing import List, Optional
-from .pymodels import *
-from .ql_conventions import *
+from . import pymodels as pym, ql_enums as qle, ql_conventions as qlc
 import QuantLib as ql
 
+from numpy import datetime64 as dt64
+
 
 def create_calendar(description: Optional[str], 
-                    holidays:List[Holiday] = [], 
+                    holidays:List[pym.Holiday] = [], 
                     mycal = None):
 
     cal = ql.BespokeCalendar(description)
@@ -27,11 +28,11 @@ def datestr_to_qldate(datestr):
     return ql.Date(vdt[2], vdt[1], vdt[0])
 
 
-def qlSchedule_from_Model(info: FixedRateBond, 
+def qlSchedule_from_Model(info: pym.FixedRateBond, 
                         ql_calendar):
     return qlSchedule(info.issue_date,
                         info.maturity,
-                        ql.Period(ql_frequency[info.settings.frequency]), 
+                        ql.Period(qlc.ql_frequency[info.settings.frequency]), 
                         ql_calendar, 
                         info.settings.business_day, 
                         info.settings.business_day, 
@@ -39,10 +40,10 @@ def qlSchedule_from_Model(info: FixedRateBond,
                         info.settings.is_eom)
 
 
-def structure_from_qlSchedule(bond_info: FixedRateBond,
+def structure_from_qlSchedule(bond_info: pym.FixedRateBond,
                             schedule: ql.QuantLib.Schedule):
     interests = ql.FixedRateLeg(schedule, 
-                            ql_day_count[bond_info.settings.day_count],
+                            qlc.ql_day_count[bond_info.settings.day_count],
                             [bond_info.face_value], 
                             [bond_info.coupon/100],
                             ql.Following)
@@ -71,7 +72,7 @@ def structure_from_qlSchedule(bond_info: FixedRateBond,
     return structures
 
 
-def qlSchedule_from_Structure(structures: List[Structure]):
+def qlSchedule_from_Structure(structures: List[pym.Structure]):
 
     dates = []
     dates.append(structures[0].start_date)
@@ -82,7 +83,7 @@ def qlSchedule_from_Structure(structures: List[Structure]):
     return qlschedule
 
 
-def qlDividendSchedule_from_CashFLows(cashflows: List[CashFlow]):
+def qlDividendSchedule_from_CashFLows(cashflows: List[pym.CashFlow]):
     schedule = ql.DividendSchedule([ ql.SimpleCashFlow(cf.amount, datestr_to_qldate(cf.date)) for cf in cashflows])
     return schedule
 
@@ -90,16 +91,16 @@ def qlDividendSchedule_from_CashFLows(cashflows: List[CashFlow]):
 def get_qlPeriod(tenor:str):
     prd = tenor[-1]
     number = int(tenor[:len(tenor)-1])
-    return  ql.Period(number, ql_tenor[prd])
+    return  ql.Period(number, qlc.ql_tenor[prd])
 
 
 def qlSchedule(issue_date: str, 
             maturity: str, 
             period: ql.QuantLib.Period, 
             ql_calendar,
-            business_day: BusinessDay, 
-            maturity_business_day: BusinessDay,
-            date_gen: DateGeneration, 
+            business_day: qle.BusinessDay, 
+            maturity_business_day: qle.BusinessDay,
+            date_gen: qle.DateGeneration, 
             eom: bool = False):
     """
     Creates list of dates. 
@@ -136,7 +137,7 @@ def qlSchedule(issue_date: str,
     return schedule
 
 
-def qlSchedule2(thebond: FixedRateBond,
+def qlSchedule2(thebond: pym.FixedRateBond,
             ql_calendar):
     
     vdate = datestr_to_qldate(thebond.issue_date)
@@ -153,25 +154,26 @@ def qlSchedule2(thebond: FixedRateBond,
     return schedule
 
 
-def qlMakeScedule(issue_date: str, maturity: str, frequency:str, ql_calendar = None,
-                business_day: Optional[BusinessDay] = None, 
-                maturity_business_day: Optional[BusinessDay] = None,
-                date_gen: Optional[DateGeneration] = None, eom: bool = False):
+def qlMakeScedule(issue_date: str, maturity: str, frequency:str, 
+            ql_calendar = None,
+                business_day: Optional[qle.BusinessDay] = None, 
+                maturity_business_day: Optional[qle.BusinessDay] = None,
+                date_gen: Optional[qle.DateGeneration] = None, eom: bool = False):
 
     vdate = datestr_to_qldate(issue_date)
     mdate = datestr_to_qldate(maturity)
     freq = ql.Period(frequency)
     if business_day:
-        ql_bus_day = ql_business_day[business_day]
+        ql_bus_day = qlc.ql_business_day[business_day]
     if maturity_business_day:
-        ql_mat_bus_day = ql_business_day[maturity_business_day]
+        ql_mat_bus_day = qlc.ql_business_day[maturity_business_day]
     if date_gen:
-        ql_date_gen = ql_date_generation[date_gen]
+        ql_date_gen = qlc.ql_date_generation[date_gen]
     schedule = ql.MakeSchedule(vdate, mdate, freq)
     return schedule
 
 
-def qlCallabilitySchedule_from_class(call_schedule: List[CallabilityPrice]):
+def qlCallabilitySchedule_from_class(call_schedule: List[pym.CallabilityPrice]):
     callability_schedule = ql.CallabilitySchedule()
     
     for calldata in call_schedule:
@@ -183,3 +185,9 @@ def qlCallabilitySchedule_from_class(call_schedule: List[CallabilityPrice]):
                                 call_date)
         callability_schedule.append(callability)
     return callability_schedule
+
+
+
+        
+
+        
\ No newline at end of file
