@@ -5,7 +5,7 @@ from .pymodels import *
 from .ql_utils import *
 from .ql_conventions import *
 from .termstructure import *
-from fpql import pymodels
+from . import pymodels
 
 
 def flat_forward():
@@ -529,4 +529,89 @@ def srmodel_info():
                             "g2_eta": 0.01,
                             "g2_rho": -0.75,
                         }
-    return callbond_model
\ No newline at end of file
+    return callbond_model
+
+
+def data_EONIA():
+    
+    depo_sett = {
+        "start_basis": StartBasis.spot, 
+        "business_day": BusinessDay.following,
+        "day_count": DayCount.act_act_act365,
+        "eom": False
+        }
+    depos = [{'tenor':'O/N', 'rate': 0.04, 'start_basis': StartBasis.today},
+            {'tenor':"T/N", 'rate': 0.04, 'start_basis': StartBasis.tom}, 
+            {'tenor':"S/N", 'rate': 0.04, 'start_basis': StartBasis.spot}]
+    depo_helper = [ql.DepositRateHelper(ql.QuoteHandle(ql.SimpleQuote(depo['rate']/100)),
+                                                ql.Period(1,ql.Days),
+                                                depo['start_basis'],
+                                                ql.TARGET(), 
+                                                ql.Following,
+                                                False,
+                                                ql.Actual360()) 
+                    for depo in depos]
+    #>>>>>>>> NOT USED >>>>>>>>>>>>>
+    depo_rates = []
+    for depo in depos:
+        rate = pymodels.Rate(**depo)
+        depo_rates.append(rate)
+    #<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
+
+    index = ql.Eonia()
+    ois = [{'tenor':"1W", 'rate': 0.07}, 
+            {'tenor':"2W", 'rate': 0.069}, 
+            {'tenor':"3W", 'rate': 0.078}]
+
+    ois_helper = [ ql.OISRateHelper(2, ql.Period(datum['tenor']),
+                                   ql.QuoteHandle(ql.SimpleQuote(datum['rate']/100)), index)
+                                    for datum in ois] 
+    #>>>>>>>> NOT USED >>>>>>>>>>>>>
+    ois_rates = []
+    for oi in ois:
+        rate = pymodels.Rate(**oi)
+        ois_rates.append(rate)
+    #<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
+    
+    ois_fwds = [{'rate': 0.046, 'start_date': '2013-01-16', "end_date": '2013-02-13'},
+            {'rate': 0.016, 'start_date': '2013-02-13', "end_date": '2013-03-13'}, 
+            {'rate': -0.007, 'start_date': '2013-03-13', "end_date": '2013-04-10'},
+            {'rate': -0.013, 'start_date': '2013-04-10', "end_date": '2013-05-08'}, 
+            {'rate': -0.014, 'start_date': '2013-05-08', "end_date": '2013-06-12'}]
+    ois_fwd_helper = [ql.DatedOISRateHelper(ql.Date(datum['start_date'], '%Y-%m-%d'), 
+                                            ql.Date(datum['end_date'],  '%Y-%m-%d'),
+                                            ql.QuoteHandle(ql.SimpleQuote(datum['rate']/100)), 
+                                            index)
+                        for datum in ois_fwds ]
+    #>>>>>>>>>> NOT USED >>>>>>>>>>>>>>>>
+    ##ois_frwd = []
+    #for ois_fwd in ois_fwds:
+    #    rate = pymodels.Rate(**ois_fwd)
+    #    ois_frwd.append(rate)
+    #<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
+
+    ois_swap = [ {'tenor':"15M", 'rate': 0.002}, 
+                {'tenor':"18M", 'rate': 0.008},
+                {'tenor':"21M", 'rate': 0.021},
+                {'tenor':"2Y", 'rate': 0.036},
+                {'tenor':"3Y", 'rate': 0.127},
+                {'tenor':"4Y", 'rate': 0.274},
+                {'tenor':"5Y", 'rate': 0.456},
+                {'tenor':"6Y", 'rate': 0.647},
+                {'tenor':"7Y", 'rate': 0.824},
+                {'tenor':"8Y", 'rate': 0.996},
+                {'tenor':"9Y", 'rate': 1.147},
+                {'tenor':"10Y", 'rate': 1.280},
+                {'tenor':"11Y", 'rate': 1.404},
+                {'tenor':"12Y", 'rate': 1.516},
+                {'tenor':"15Y", 'rate': 1.764},
+                {'tenor':"20Y", 'rate': 1.939},
+                {'tenor':"25Y", 'rate': 2.003},
+                {'tenor':"30Y", 'rate': 2.038}
+                ]
+    ois_swap_helper = [ql.OISRateHelper(2, 
+                                        ql.Period(datum['tenor']),
+                                        ql.QuoteHandle(ql.SimpleQuote(datum['rate']/100)), index)
+                        for datum in ois_swap]
+    
+    return depo_helper, ois_helper, ois_fwd_helper, ois_swap_helper
\ No newline at end of file
